@@ -55,9 +55,6 @@ class Resource(object):
             if hasattr(self, "object_id"):
                 url = urlparse.urljoin(url, str(self.object_id))
 
-            if not url.endswith("/"):
-                url += "/"
-
         if "body" in kwargs:
             body = kwargs.pop("body")
         else:
@@ -131,9 +128,8 @@ class APIMeta(object):
     default_format = "json"
 
     http = {
-        "schema": "http",
-        "hostname": None,
-        "port": "80",
+        "scheme": "http",
+        "netloc": None,
         "path": "/",
 
         "params": "",
@@ -154,18 +150,18 @@ class APIMeta(object):
 
     @property
     def base_url(self):
-        ORDERING = ["schema", "hostname", "port", "path", "params", "query", "fragment"]
+        ORDERING = ["scheme", "netloc", "path", "params", "query", "fragment"]
         urlparts = []
         for key in ORDERING:
             if key in ["path"]:
                 urlparts.append("")
             else:
                 urlparts.append(self.http[key])
-        return urlparse.urlunparse(urlparts[:1] + [":".join([str(x) for x in urlparts[1:3]])] + urlparts[3:])
+        return urlparse.urlunparse(urlparts)
 
     @property
     def api_url(self):
-        ORDERING = ["schema", "hostname", "port", "path", "params", "query", "fragment"]
+        ORDERING = ["schema", "netloc", "path", "params", "query", "fragment"]
         urlparts = []
         for key in ORDERING:
             urlparts.append(self.http[key])
@@ -212,7 +208,7 @@ class API(object):
         except KeyError:
             self._meta.resources[item] = Resource(
                 self._meta.base_url,
-                endpoint=urlparse.urljoin(self._meta.http["path"], item) + "/",
+                endpoint=urlparse.urljoin(self._meta.http["path"], item),
                 format=self._meta.default_format,
                 authentication=self._meta.authentication
             )
